﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text.RegularExpressions;
using System.Threading;
using System.Web;

namespace PayPool.Demo.Common
{

    /// <summary>
    /// 字符串帮助类
    /// </summary>
    public class StringHelper
    {
        private static readonly object Locker = new object();
        private static int _sn = 0;

        /// <summary>
        /// 防止创建类的实例
        /// </summary>
        private StringHelper() { }

        /// <summary>
        /// 生成时间戳，标准北京时间，时区为东八区，自1970年1月1日 0点0分0秒以来的秒数
        /// </summary>
        /// <returns></returns>
        public static string GenerateTimeStamp()
        {
            TimeSpan ts = DateTime.UtcNow - new DateTime(1970, 1, 1, 0, 0, 0, 0);
            return Convert.ToInt64(ts.TotalMilliseconds).ToString();
        }

        /// <summary>
        /// 生成随机串，随机串包含字母或数字
        /// </summary>
        /// <returns></returns>
        public static string GenerateNonceStr()
        {
            return Guid.NewGuid().ToString().Replace("-", "");
        }
               
        /// <summary>
        /// 不重复编号
        /// </summary>
        /// <returns></returns>
        public static string GenerateId()
        {
            lock (Locker)  //lock 关键字可确保当一个线程位于代码的临界区时，另一个线程不会进入该临界区。
            {
                if (_sn == 999)
                {
                    _sn = 0;
                }
                else
                {
                    _sn++;
                }

                Thread.Sleep(100);

                return DateTime.Now.ToString("yyyyMMddHHmmss") + _sn.ToString().PadLeft(3, '0');
            }
        }

        /// <summary>
        /// 流水号
        /// </summary>
        /// <returns></returns>
        public static string SequenceId()
        {
            lock (Locker)  //lock 关键字可确保当一个线程位于代码的临界区时，另一个线程不会进入该临界区。
            {
                if (_sn == 999999)
                {
                    _sn = 0;
                }
                else
                {
                    _sn++;
                }

                Thread.Sleep(100);

                return _sn.ToString().PadLeft(6, '0');
            }
        }

        /// <summary>
        /// 生成用户编号
        /// </summary>
        /// <returns></returns>
        public static string GenerateUserId()
        {
            lock (Locker)  //lock 关键字可确保当一个线程位于代码的临界区时，另一个线程不会进入该临界区。
            {
                if (_sn == 9999)
                {
                    _sn = 0;
                }
                else
                {
                    _sn++;
                }

                Thread.Sleep(100);

                return DateTime.Now.ToString("yyyyMMddHHmmss") + _sn.ToString().PadLeft(4, '0');
            }
        }
        
    }
}